<?php

namespace Drupal\Tests\fillpdf\Functional;

use Drupal\Tests\file\Functional\FileFieldTestBase;
use Drupal\Tests\fillpdf\Traits\TestFillPdfTrait;
use Drupal\Tests\fillpdf\Traits\TestImageFieldTrait;
use Drupal\user\Entity\Role;

/**
 * Base class that can be inherited by FillPDF tests.
 */
abstract class FillPdfTestBase extends FileFieldTestBase {

  use TestFillPdfTrait;
  use TestImageFieldTrait;

  /**
   * @var string
   */
  protected $defaultTheme = 'stark';

  /**
   * Modules to enable.
   *
   * The test runner will merge the $modules lists from this class, the class
   * it extends, and so on up the class hierarchy. It is not necessary to
   * include modules in your list that a parent class has already declared.
   *
   * @var string[]
   *
   * @see \Drupal\Tests\BrowserTestBase::installDrupal()
   */
  public static $modules = ['image', 'fillpdf_test'];

  /**
   * The FillPdf backend service manager.
   *
   * @var \Drupal\fillpdf\Plugin\PdfBackendManager
   */
  protected $backendServiceManager;

  /**
   * The FillPDF link manipulator service.
   *
   * @var \Drupal\fillpdf\Service\FillPdfLinkManipulator
   */
  protected $linkManipulator;

  /**
   * A test image.
   *
   * @var \Drupal\file\Entity\File
   */
  protected $testImage;

  /**
   * {@inheritdoc}
   */
  protected function setUp() {
    parent::setUp();

    // Grant additional permissions to the logged-in admin user.
    $existing_user_roles = $this->adminUser->getRoles(TRUE);
    $role_to_modify = Role::load(end($existing_user_roles));
    $this->grantPermissions($role_to_modify, [
      'administer pdfs',
      'create article content',
      'edit any article content',
      'delete any article content',
    ]);

    $this->testImage = $this->getTestFile('image');

    $this->configureFillPdf();

    $this->backendServiceManager = $this->container->get('plugin.manager.fillpdf_backend_service');
    $this->linkManipulator = $this->container->get('fillpdf.link_manipulator');
  }

}
